//
//  XCTestCase+KakaoPartnerSDKSampleUITests.swift
//  KakaoPartnerSDKSampleUITests
//
//  Created by kakao on 2023/07/26.
//  Copyright © 2023 apiteam. All rights reserved.
//

import Foundation
import XCTest
import SBTUITestTunnelClient

extension XCTestCase {    
    func getTestDataPath(moduleAlias: String, snakeApiPath: String) -> String {
        return #file.replacingOccurrences(of: "KakaoPartnerSDKSample/KakaoPartnerSDKSampleUITests/XCTestCase+KakaoPartnerSDKSampleUITests.swift", with: "KakaoOpenSDK/kakao-sdk-test-data/\(moduleAlias)/\(snakeApiPath)/")
    }
    
    func getContentsUrls(apiPath: String, moduleAlias: String) throws -> [URL] {
        let snakeApiPath = String(apiPath.replacingOccurrences(of: "/", with: "_").dropFirst())
        print(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> \(snakeApiPath) ")
        
        let directory = getTestDataPath(moduleAlias: moduleAlias, snakeApiPath: snakeApiPath)
        print(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> \(directory) ")
        
        let contents = try FileManager.default.contentsOfDirectory(at: URL(fileURLWithPath: directory, isDirectory: true), includingPropertiesForKeys: [], options: [])
            .filter { $0.pathExtension == "json" }
        
        return contents
    }
    
    func stubData(apiPath: String, module: String, method: String, fileName: String? = nil, host: String = "https://kapi.kakao.com") {
        guard let urlPath = try? getContentsUrls(apiPath: apiPath, moduleAlias: module) else {
            XCTFail("Content Path not found: \(module), \(apiPath)")
            return
        }
        
        var firstUrl: URL? = nil
        if let fileName = fileName {
            firstUrl = urlPath.filter({ $0.absoluteString.contains(fileName) }).first
        } else {
            firstUrl = urlPath.first
        }
        
        guard let firstUrl = firstUrl, let contentData = try? Data(contentsOf: firstUrl) else {
            XCTFail("Content Data not found")
            return
        }
        
        guard let contentJson = try? JSONSerialization.jsonObject(with: contentData) as? [String:Any] else {
            XCTFail("Content Json not found")
            return
        }
        
        app.stubRequests(matching: SBTRequestMatch.init(url: "\(host)\(apiPath)", method: method), response: SBTStubResponse(response: contentJson))
    }
    
}
